@@ -6,7 +6,6 @@
 
 OL_BIN=/usr/local/openldap/bin
 OL_SBIN=/usr/local/openldap/sbin
-OL_MAN=/usr/local/openldap/share/man
 
 PATH="$PATH:$OL_BIN"
 
@@ -16,5 +15,3 @@ then
 fi
 
 export PATH
-
-export MANPATH="$MANPATH:$OL_MAN"
